@@ -11,6 +11,7 @@ from qqbot.model.announce import (
     Announce,
     CreateAnnounceRequest,
     CreateChannelAnnounceRequest,
+    RecommendChannelRequest,
 )
 from qqbot.model.api_permission import (
     APIPermission,
@@ -47,6 +48,7 @@ from qqbot.model.message import (
     MessagesPager,
 )
 from qqbot.model.mute import MuteOption
+from qqbot.model.pins_message import PinsMessage
 from qqbot.model.schedule import (
     Schedule,
     GetSchedulesRequest,
@@ -681,6 +683,20 @@ class AnnouncesAPI(APIBase):
         response = self.http.delete(url)
         return response.status_code == HttpStatus.NO_CONTENT
 
+    def post_recommended_channels(
+        self, guild_id: str, request: RecommendChannelRequest
+    ) -> Announce:
+        """
+        创建子频道类型的频道全局公告
+
+        :param guild_id: 频道ID
+        :param request: RecommendChannelRequest 对象
+        """
+        url = get_url(APIConstant.guildAnnounceURI, self.is_sandbox).format(guild_id=guild_id)
+        request_json = JsonUtil.obj2json_serialize(request)
+        response = self.http.post(url, request_json)
+        return json.loads(response.content, object_hook=Announce)
+
 
 class APIPermissionAPI(APIBase):
     """接口权限接口"""
@@ -802,3 +818,80 @@ class ScheduleAPI(APIBase):
         )
         response = self.http.delete(url)
         return response.status_code == HttpStatus.NO_CONTENT
+
+
+class ReactionAPI(APIBase):
+    """表情表态接口"""
+
+    def put_reaction(self, channel_id: str, message_id: str, emo_type: int, emo_id: str):
+        """
+        对一条消息进行表情表态
+
+        :param channel_id: 子频道ID
+        :param message_id: 该条消息对应的id
+        :param emo_type: 表情类型
+        :param emo_id: 表情ID
+        """
+        url = get_url(APIConstant.reactionURI, self.is_sandbox).format(
+            channel_id=channel_id, message_id=message_id, type=emo_type, id=emo_id
+        )
+        response = self.http.put(url)
+        return response.status_code == HttpStatus.NO_CONTENT
+
+    def delete_reaction(self, channel_id: str, message_id: str, emo_type: int, emo_id: str):
+        """
+        删除自己对消息的进行表情表态
+
+        :param channel_id: 子频道ID
+        :param message_id: 该条消息对应的id
+        :param emo_type: 表情类型
+        :param emo_id: 表情ID
+        """
+        url = get_url(APIConstant.reactionURI, self.is_sandbox).format(
+            channel_id=channel_id, message_id=message_id, type=emo_type, id=emo_id
+        )
+        response = self.http.delete(url)
+        return response.status_code == HttpStatus.NO_CONTENT
+
+
+class PinsAPI(APIBase):
+    """精华消息API"""
+
+    def put_pin(self, channel_id: str, message_id: str) -> PinsMessage:
+        """
+        在子频道内添加一条精华消息
+        每个子频道最多20条精华消息
+        只有可见的消息才能被设置为精华消息
+        返回对象中 message_ids 为当前请求后子频道内所有精华消息数组
+
+        :param channel_id: 子频道ID
+        :param message_id: 该条消息对应的id
+        """
+        url = get_url(APIConstant.changePinsURI, self.is_sandbox).format(
+            channel_id=channel_id, message_id=message_id
+        )
+        response = self.http.put(url)
+        return json.loads(response.content, object_hook=PinsMessage)
+
+    def delete_pin(self, channel_id: str, message_id: str):
+        """
+        用于移除子频道下的一条精华消息
+
+        :param channel_id: 子频道ID
+        :param message_id: 该条消息对应的id
+        """
+        url = get_url(APIConstant.changePinsURI, self.is_sandbox).format(
+            channel_id=channel_id, message_id=message_id
+        )
+        response = self.http.delete(url)
+        return response.status_code == HttpStatus.NO_CONTENT
+
+    def get_pins(self, channel_id: str) -> PinsMessage:
+        """
+        用于获取子频道内的所有精华消息
+        成功后返回 PinsMessage 对象
+        :param channel_id: 子频道ID
+        """
+        url = get_url(APIConstant.getPinsURI, self.is_sandbox).format(channel_id=channel_id)
+        response = self.http.get(url)
+        return json.loads(response.content, object_hook=PinsMessage)
